Functions
- clear_
bit - get_bit
- has_
bits_ in_ range - Check if there are any set bits in the range [start_pos, end_pos) (exclusive end) Optimized for range queries using bit manipulation
- rank
- rank_
cached - optimized rank using cached halfway popcount if pos is in second half, start counting from cached midpoint
- select
- select_
cached - optimized select using cached halfway popcount if target rank is past cached count, start from midpoint
- set_bit